From: Martin Schwidefsky <schwidefsky@de.ibm.com>
To: akpm@osdl.org, linux-kernel@vger.kernel.org
Subject: [patch 6/9] s390: z90crypt reader task rescheduling.
Date: Wed, 2 Mar 2005 17:46:09 +0100 [thread overview]
Message-ID: <20050302164609.GF27829@mschwid3.boeblingen.de.ibm.com> (raw)
[patch 6/9] s390: z90crypt reader task rescheduling.
From: Eric Rossman <edrossma@us.ibm.com>
z90crypt device driver changes:
- Correct the condition for which the reader task is scheduled to run.
Signed-off-by: Martin Schwidefsky <schwidefsky@de.ibm.com>
diffstat:
drivers/s390/crypto/z90main.c | 6 +++---
1 files changed, 3 insertions(+), 3 deletions(-)
diff -urN linux-2.6/drivers/s390/crypto/z90main.c linux-2.6-patched/drivers/s390/crypto/z90main.c
--- linux-2.6/drivers/s390/crypto/z90main.c 2005-03-02 08:37:30.000000000 +0100
+++ linux-2.6-patched/drivers/s390/crypto/z90main.c 2005-03-02 17:00:13.000000000 +0100
@@ -2657,8 +2657,8 @@
/**
* we use workavail = 2 to ensure 2 passes with nothing dequeued before
* exiting the loop. If pendingq_count == 0 after the loop, there is no
* work remaining on the queues.
*/
resp_addr = 0;
workavail = 2;
@@ -2697,7 +2697,7 @@
spin_unlock_irq(&queuespinlock);
}
- if (pendingq_count)
+ if (pendingq_count + requestq_count)
z90crypt_schedule_reader_timer();
}
reply other threads:[~2005-03-02 16:49 UTC|newest]
Thread overview: [no followups] expand[flat|nested] mbox.gz Atom feed
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=20050302164609.GF27829@mschwid3.boeblingen.de.ibm.com \
--to=schwidefsky@de.ibm.com \
--cc=akpm@osdl.org \
--cc=linux-kernel@vger.kernel.org \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
@@ -2657,8 +2657,8 @@
/**
* we use workavail = 2 to ensure 2 passes with nothing dequeued before
- * exiting the loop. If pendingq_count == 0 after the loop, there is no
- * work remaining on the queues.
+ * exiting the loop. If (pendingq_count+requestq_count) == 0 after the
+ * loop, there is no work remaining on the queues.
*/
resp_addr = 0;
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox
all inboxes | Powered by JetHome®